==> estateplat-common-1.2.4-20220622.065714-1051-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/DjfDjSqNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.estateplat.utils.JaxbNotNullDateAdapter;
import cn.gtmap.sdk.mybatis.plugin.annotation.Crypt;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

@XmlRootElement(name = "DJF_DJ_SQ")
@Table(name = "DJF_DJ_SQ")
public class DjfDjSqNew implements Serializable, AccessData {
    final static String ysdm = "6004010000";//要素代码
    private String ywh;//业务号
    private String qlrmc;//权利人名称
    private String qlrzjzl;//权利人证件种类
    @Crypt
    private String qlrzjh;//权利人证件号
    private String qlrtxdz;//权利人通讯地址
    private String qlryb;//权利人邮编
    private String qlrfrmc;//权利人法人名称
    private String qlrfrdh;//权利人法人电话
    private String qlrdlrmc;//权利人代理人名称
    private String qlrdlrdh;//权利人代理人电话
    private String qlrdljg;//权利人代理机构
    private String ywrmc;//义务人名称
    private String ywrzjzl;//义务人证件种类
    @Crypt
    private String ywrzjh;//义务人证件号
    private String ywrtxdz;//义务人通讯地址
    private String ywryb;//义务人邮编
    private String ywrfrmc;//义务人法人名称
    private String ywrfrdh;//义务人法人电话
    private String ywrdlrmc;//义务人代理人名称
    private String ywrdlrdh;//义务人代理人电话
    private String ywrdljg;//义务人代理机构
    private String bz;//备注
    private String qxdm;//区县代码
    @Crypt
    private String qlrdh;//权利人电话
    @Crypt
    private String ywrdh;//义务人电话

    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    private Date sqsj;
    @XmlAttribute(name = "SQSJ")
    @XmlJavaTypeAdapter(JaxbNotNullDateAdapter.class)
    public Date getSqsj() {
        return sqsj;
    }

    public void setSqsj(Date sqsj) {
        this.sqsj = sqsj;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "QLRMC")
    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    @XmlAttribute(name = "QLRZJZL")
    public String getQlrzjzl() {
        return qlrzjzl;
    }

    public void setQlrzjzl(String qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    @XmlAttribute(name = "QLRZJH")
    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    @XmlAttribute(name = "QLRTXDZ")
    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    @XmlAttribute(name = "QLRYB")
    public String getQlryb() {
        return qlryb;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    @XmlAttribute(name = "QLRFRMC")
    public String getQlrfrmc() {
        return qlrfrmc;
    }

    public void setQlrfrmc(String qlrfrmc) {
        this.qlrfrmc = qlrfrmc;
    }

    @XmlAttribute(name = "QLRFRDH")
    public String getQlrfrdh() {
        return qlrfrdh;
    }

    public void setQlrfrdh(String qlrfrdh) {
        this.qlrfrdh = qlrfrdh;
    }

    @XmlAttribute(name = "QLRDLRMC")
    public String getQlrdlrmc() {
        return qlrdlrmc;
    }

    public void setQlrdlrmc(String qlrdlrmc) {
        this.qlrdlrmc = qlrdlrmc;
    }

    @XmlAttribute(name = "QLRDLRDH")
    public String getQlrdlrdh() {
        return qlrdlrdh;
    }

    public void setQlrdlrdh(String qlrdlrdh) {
        this.qlrdlrdh = qlrdlrdh;
    }

    @XmlAttribute(name = "QLRDLJG")
    public String getQlrdljg() {
        return qlrdljg;
    }

    public void setQlrdljg(String qlrdljg) {
        this.qlrdljg = qlrdljg;
    }

    @XmlAttribute(name = "YWRMC")
    public String getYwrmc() {
        return ywrmc;
    }

    public void setYwrmc(String ywrmc) {
        this.ywrmc = ywrmc;
    }

    @XmlAttribute(name = "YWRZJZL")
    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    @XmlAttribute(name = "YWRZJH")
    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    @XmlAttribute(name = "YWRTXDZ")
    public String getYwrtxdz() {
        return ywrtxdz;
    }

    public void setYwrtxdz(String ywrtxdz) {
        this.ywrtxdz = ywrtxdz;
    }

    @XmlAttribute(name = "YWRYB")
    public String getYwryb() {
        return ywryb;
    }

    public void setYwryb(String ywryb) {
        this.ywryb = ywryb;
    }

    @XmlAttribute(name = "YWRFRMC")
    public String getYwrfrmc() {
        return ywrfrmc;
    }

    public void setYwrfrmc(String ywrfrmc) {
        this.ywrfrmc = ywrfrmc;
    }

    @XmlAttribute(name = "YWRFRDH")
    public String getYwrfrdh() {
        return ywrfrdh;
    }

    public void setYwrfrdh(String ywrfrdh) {
        this.ywrfrdh = ywrfrdh;
    }

    @XmlAttribute(name = "YWRDLRMC")
    public String getYwrdlrmc() {
        return ywrdlrmc;
    }

    public void setYwrdlrmc(String ywrdlrmc) {
        this.ywrdlrmc = ywrdlrmc;
    }

    @XmlAttribute(name = "YWRDLRDH")
    public String getYwrdlrdh() {
        return ywrdlrdh;
    }

    public void setYwrdlrdh(String ywrdlrdh) {
        this.ywrdlrdh = ywrdlrdh;
    }

    @XmlAttribute(name = "YWRDLJG")
    public String getYwrdljg() {
        return ywrdljg;
    }

    public void setYwrdljg(String ywrdljg) {
        this.ywrdljg = ywrdljg;
    }

    @XmlAttribute(name = "BZ")
    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    @XmlTransient
    public String getQlrdh() {
        return qlrdh;
    }

    public void setQlrdh(String qlrdh) {
        this.qlrdh = qlrdh;
    }

    @XmlTransient
    public String getYwrdh() {
        return ywrdh;
    }

    public void setYwrdh(String ywrdh) {
        this.ywrdh = ywrdh;
    }
}

==> estateplat-common-1.2.4-20240201.062650-1218-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/DjfDjSqNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.sdk.mybatis.plugin.annotation.Crypt;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

@XmlRootElement(name = "DJF_DJ_SQ")
@Table(name = "DJF_DJ_SQ")
public class DjfDjSqNew implements Serializable, AccessData {
    final static String ysdm = "6004010000";//要素代码
    private String ywh;//业务号
    private String qlrmc;//权利人名称
    private String qlrzjzl;//权利人证件种类
    @Crypt
    private String qlrzjh;//权利人证件号
    private String qlrtxdz;//权利人通讯地址
    private String qlryb;//权利人邮编
    private String qlrfrmc;//权利人法人名称
    private String qlrfrdh;//权利人法人电话
    private String qlrdlrmc;//权利人代理人名称
    private String qlrdlrdh;//权利人代理人电话
    private String qlrdljg;//权利人代理机构
    private String ywrmc;//义务人名称
    private String ywrzjzl;//义务人证件种类
    @Crypt
    private String ywrzjh;//义务人证件号
    private String ywrtxdz;//义务人通讯地址
    private String ywryb;//义务人邮编
    private String ywrfrmc;//义务人法人名称
    private String ywrfrdh;//义务人法人电话
    private String ywrdlrmc;//义务人代理人名称
    private String ywrdlrdh;//义务人代理人电话
    private String ywrdljg;//义务人代理机构
    private String bz;//备注
    private String qxdm;//区县代码
    @Crypt
    private String qlrdh;//权利人电话
    @Crypt
    private String ywrdh;//义务人电话

    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    private Date sqsj;
    @XmlAttribute(name = "SQSJ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getSqsj() {
        return sqsj;
    }

    public void setSqsj(Date sqsj) {
        this.sqsj = sqsj;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "QLRMC")
    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    @XmlAttribute(name = "QLRZJZL")
    public String getQlrzjzl() {
        return qlrzjzl;
    }

    public void setQlrzjzl(String qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    @XmlAttribute(name = "QLRZJH")
    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    @XmlAttribute(name = "QLRTXDZ")
    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    @XmlAttribute(name = "QLRYB")
    public String getQlryb() {
        return qlryb;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    @XmlAttribute(name = "QLRFRMC")
    public String getQlrfrmc() {
        return qlrfrmc;
    }

    public void setQlrfrmc(String qlrfrmc) {
        this.qlrfrmc = qlrfrmc;
    }

    @XmlAttribute(name = "QLRFRDH")
    public String getQlrfrdh() {
        return qlrfrdh;
    }

    public void setQlrfrdh(String qlrfrdh) {
        this.qlrfrdh = qlrfrdh;
    }

    @XmlAttribute(name = "QLRDLRMC")
    public String getQlrdlrmc() {
        return qlrdlrmc;
    }

    public void setQlrdlrmc(String qlrdlrmc) {
        this.qlrdlrmc = qlrdlrmc;
    }

    @XmlAttribute(name = "QLRDLRDH")
    public String getQlrdlrdh() {
        return qlrdlrdh;
    }

    public void setQlrdlrdh(String qlrdlrdh) {
        this.qlrdlrdh = qlrdlrdh;
    }

    @XmlAttribute(name = "QLRDLJG")
    public String getQlrdljg() {
        return qlrdljg;
    }

    public void setQlrdljg(String qlrdljg) {
        this.qlrdljg = qlrdljg;
    }

    @XmlAttribute(name = "YWRMC")
    public String getYwrmc() {
        return ywrmc;
    }

    public void setYwrmc(String ywrmc) {
        this.ywrmc = ywrmc;
    }

    @XmlAttribute(name = "YWRZJZL")
    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    @XmlAttribute(name = "YWRZJH")
    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    @XmlAttribute(name = "YWRTXDZ")
    public String getYwrtxdz() {
        return ywrtxdz;
    }

    public void setYwrtxdz(String ywrtxdz) {
        this.ywrtxdz = ywrtxdz;
    }

    @XmlAttribute(name = "YWRYB")
    public String getYwryb() {
        return ywryb;
    }

    public void setYwryb(String ywryb) {
        this.ywryb = ywryb;
    }

    @XmlAttribute(name = "YWRFRMC")
    public String getYwrfrmc() {
        return ywrfrmc;
    }

    public void setYwrfrmc(String ywrfrmc) {
        this.ywrfrmc = ywrfrmc;
    }

    @XmlAttribute(name = "YWRFRDH")
    public String getYwrfrdh() {
        return ywrfrdh;
    }

    public void setYwrfrdh(String ywrfrdh) {
        this.ywrfrdh = ywrfrdh;
    }

    @XmlAttribute(name = "YWRDLRMC")
    public String getYwrdlrmc() {
        return ywrdlrmc;
    }

    public void setYwrdlrmc(String ywrdlrmc) {
        this.ywrdlrmc = ywrdlrmc;
    }

    @XmlAttribute(name = "YWRDLRDH")
    public String getYwrdlrdh() {
        return ywrdlrdh;
    }

    public void setYwrdlrdh(String ywrdlrdh) {
        this.ywrdlrdh = ywrdlrdh;
    }

    @XmlAttribute(name = "YWRDLJG")
    public String getYwrdljg() {
        return ywrdljg;
    }

    public void setYwrdljg(String ywrdljg) {
        this.ywrdljg = ywrdljg;
    }

    @XmlAttribute(name = "BZ")
    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    @XmlTransient
    public String getQlrdh() {
        return qlrdh;
    }

    public void setQlrdh(String qlrdh) {
        this.qlrdh = qlrdh;
    }

    @XmlTransient
    public String getYwrdh() {
        return ywrdh;
    }

    public void setYwrdh(String ywrdh) {
        this.ywrdh = ywrdh;
    }
}
